summaryrefslogtreecommitdiffstats
path: root/kmail/kmaccount.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmaccount.h')
-rw-r--r--kmail/kmaccount.h64
1 files changed, 32 insertions, 32 deletions
diff --git a/kmail/kmaccount.h b/kmail/kmaccount.h
index 9a896e198..c54611cbd 100644
--- a/kmail/kmaccount.h
+++ b/kmail/kmaccount.h
@@ -23,10 +23,10 @@
#include <kprocess.h>
#include <kaccount.h>
-#include <qstring.h>
-#include <qguardedptr.h>
-#include <qvaluelist.h>
-#include <qmap.h>
+#include <tqstring.h>
+#include <tqguardedptr.h>
+#include <tqvaluelist.h>
+#include <tqmap.h>
#include "kmmessage.h"
class QTimer;
@@ -47,14 +47,14 @@ using KMail::FolderJob;
using KPIM::ProgressItem;
class KMAccount;
-typedef QValueList< ::KMAccount* > AccountList;
+typedef TQValueList< ::KMAccount* > AccountList;
class KMPrecommand : public QObject
{
Q_OBJECT
public:
- KMPrecommand(const QString &precommand, QObject *parent = 0);
+ KMPrecommand(const TQString &precommand, TQObject *parent = 0);
virtual ~KMPrecommand();
bool start();
@@ -66,11 +66,11 @@ signals:
protected:
KProcess mPrecommandProcess;
- QString mPrecommand;
+ TQString mPrecommand;
};
-class KMAccount: public QObject, public KAccount
+class KMAccount: public TQObject, public KAccount
{
Q_OBJECT
friend class KMail::AccountManager;
@@ -90,17 +90,17 @@ public:
/**
* Returns type of the account
*/
- virtual QString type() const { return QString::null; }
+ virtual TQString type() const { return TQString::null; }
/**
* Reimplemented, set account name
*/
- virtual void setName(const QString&);
+ virtual void setName(const TQString&);
/**
* Account name (reimpl because of ambiguous QObject::name())
*/
- virtual QString name() const { return KAccount::name(); }
+ virtual TQString name() const { return KAccount::name(); }
/**
* Set password to "" (empty string)
@@ -126,8 +126,8 @@ public:
/**
* the id of the trash folder (if any) for this account
*/
- QString trash() const { return mTrash; }
- virtual void setTrash(const QString& aTrash) { mTrash = aTrash; }
+ TQString trash() const { return mTrash; }
+ virtual void setTrash(const TQString& aTrash) { mTrash = aTrash; }
/**
* Process new mail for this account if one arrived. Returns TRUE if new
@@ -181,8 +181,8 @@ public:
/**
* Pre command
*/
- const QString& precommand(void) const { return mPrecommand; }
- virtual void setPrecommand(const QString &cmd) { mPrecommand = cmd; }
+ const TQString& precommand(void) const { return mPrecommand; }
+ virtual void setPrecommand(const TQString &cmd) { mPrecommand = cmd; }
/**
* Runs the precommand. If the precommand is empty, the method
@@ -190,16 +190,16 @@ public:
*
* @return True if successful, false otherwise
*/
- bool runPrecommand(const QString &precommand);
+ bool runPrecommand(const TQString &precommand);
/**
* Very primitive en/de-cryption so that the password is not
* readable in the config file. But still very easy breakable.
*/
- static QString encryptStr(const QString& inStr);
- static QString decryptStr(const QString& inStr) { return encryptStr(inStr); }
+ static TQString encryptStr(const TQString& inStr);
+ static TQString decryptStr(const TQString& inStr) { return encryptStr(inStr); }
- static QString importPassword(const QString &);
+ static TQString importPassword(const TQString &);
/** @return whether this account has an inbox */
bool hasInbox() const { return mHasInbox; }
@@ -264,7 +264,7 @@ signals:
* Emitted after the mail check is finished.
* @param newInFolder number of new messages for each folder
**/
- virtual void newMailsProcessed( const QMap<QString, int> & newInFolder );
+ virtual void newMailsProcessed( const TQMap<TQString, int> & newInFolder );
protected slots:
virtual void mailCheck();
@@ -272,7 +272,7 @@ protected slots:
virtual void precommandExited(bool);
protected:
- KMAccount( AccountManager* owner, const QString& accountName, uint id);
+ KMAccount( AccountManager* owner, const TQString& accountName, uint id);
/**
* Does filtering and storing in a folder for the given message.
@@ -301,14 +301,14 @@ protected:
* @param folderId the id of the folder
* @param num the number of new message in this folder
*/
- void addToNewInFolder( QString folderId, int num );
+ void addToNewInFolder( TQString folderId, int num );
protected:
- QString mPrecommand;
- QString mTrash;
+ TQString mPrecommand;
+ TQString mTrash;
AccountManager* mOwner;
- QGuardedPtr<KMAcctFolder> mFolder;
- QTimer *mTimer;
+ TQGuardedPtr<KMAcctFolder> mFolder;
+ TQTimer *mTimer;
int mInterval; // this is a switch and a scalar at the same time. If it is 0,
// interval mail checking is turned off and the interval spinbox proposes a
// default value. If it is non-null, it is the count of minutes between two
@@ -317,20 +317,20 @@ protected:
bool mExclude;
bool mCheckingMail : 1;
bool mPrecommandSuccess;
- QValueList<KMMessage*> mReceipts;
- QPtrList<FolderJob> mJobList;
+ TQValueList<KMMessage*> mReceipts;
+ TQPtrList<FolderJob> mJobList;
bool mHasInbox : 1;
- QGuardedPtr<ProgressItem> mMailCheckProgressItem;
+ TQGuardedPtr<ProgressItem> mMailCheckProgressItem;
uint mIdentityId;
private:
/**
* avoid compiler warning about hidden virtual
*/
- virtual void setName( const char *name ) { QObject::setName( name ); }
+ virtual void setName( const char *name ) { TQObject::setName( name ); }
private:
// for detailed (per folder) new mail notification
- QMap<QString, int> mNewInFolder;
+ TQMap<TQString, int> mNewInFolder;
};
#endif /*kmaccount_h*/
@@ -90,17 +90,17 @@ public:
/**
- * Account name (reimpl because of ambiguous QObject::name())
+ * Account name (reimpl because of ambiguous TQObject::name())
*/